@@ -3,14 +3,25 @@ from zipfile import ZipFile
 from pathlib import Path
 import json
 import random
+import base64
 import glob
 import requests
+import labelme
 import shutil
 import os
 import csv
 import ast
 import xml.etree.ElementTree as ET
 
+class NpEncoder(json.JSONEncoder):
+    def default(self, obj):
+        if isinstance(obj, np.integer):
+            return int(obj)
+        if isinstance(obj, np.floating):
+            return float(obj)
+        if isinstance(obj, np.ndarray):
+            return obj.tolist()
+        return json.JSONEncoder.default(self, obj)
 
 class GenerateAnnotation():   
     def __init__(self, export_format, annotations, labels=[], shape_type='rectangle', 
@@ -258,6 +269,8 @@ class GenerateAnnotation():
                 img_path, label, shape_type, points = ppt
                 #update imagePath
                 output_json_dict['imagePath']=img_path
+                data = labelme.LabelFile.load_image_file(os.path.join(self.train_path, 'images'))
+                output_json_dict['imageData']=base64.b64encode(data).decode('utf-8')
                 #shapes info
                 shapes_info = {
                     'label':'',
@@ -273,7 +286,7 @@ class GenerateAnnotation():
             train_out_annotation_dir = self.valid_path(os.path.join(self.train_path, 'annotations'))
             out_annotation_path = os.path.join(train_out_annotation_dir, self.replace_extension(image_ppt[0][0], '.json'))
             with open(out_annotation_path, 'w') as f:
-                output_json = json.dumps(output_json_dict, indent=4)
+                output_json = json.dumps(output_json_dict, indent=4, cls=NpEncoder)
                 f.write(output_json)
         for image_ppt in self.ppts_test:
             #download image
@@ -288,6 +301,8 @@ class GenerateAnnotation():
                 img_path, label, shape_type, points = ppt
                 #update imagePath
                 output_json_dict['imagePath']=img_path
+                data = labelme.LabelFile.load_image_file(os.path.join(self.test_path, 'images'))
+                output_json_dict['imageData']=base64.b64encode(data).decode('utf-8')
                 #shapes info
                 shapes_info = {
                     'label':'',
@@ -303,7 +318,7 @@ class GenerateAnnotation():
             test_out_annotation_dir = self.valid_path(os.path.join(self.test_path, 'annotations'))
             out_annotation_path = os.path.join(test_out_annotation_dir, self.replace_extension(image_ppt[0][0], '.json'))
             with open(out_annotation_path, 'w') as f:
-                output_json = json.dumps(output_json_dict, indent=4)
+                output_json = json.dumps(output_json_dict, indent=4, cls=NpEncoder)
                 f.write(output_json)
         for image_ppt in self.ppts_valid:
             #download image
@@ -318,6 +333,8 @@ class GenerateAnnotation():
                 img_path, label, shape_type, points = ppt
                 #update imagePath
                 output_json_dict['imagePath']=img_path
+                data = labelme.LabelFile.load_image_file(os.path.join(self.validation_path, 'images'))
+                output_json_dict['imageData']=base64.b64encode(data).decode('utf-8')
                 #shapes info
                 shapes_info = {
                     'label':'',
@@ -333,7 +350,7 @@ class GenerateAnnotation():
             validation_out_annotation_dir = self.valid_path(os.path.join(self.validation_path, 'annotations'))
             out_annotation_path = os.path.join(validation_out_annotation_dir, self.replace_extension(image_ppt[0][0], '.json'))
             with open(out_annotation_path, 'w') as f:
-                output_json = json.dumps(output_json_dict, indent=4)
+                output_json = json.dumps(output_json_dict, indent=4, cls=NpEncoder)
                 f.write(output_json)
         print('All done!')
 
